@@ -19,8 +19,10 @@ import contextlib
 import six
 import stevedore.driver
 
+from taskflow import exceptions as exc
 from taskflow.openstack.common import importutils
 from taskflow.persistence import backends as p_backends
+from taskflow.utils import misc
 from taskflow.utils import persistence_utils as p_utils
 from taskflow.utils import reflection
 
@@ -29,15 +31,23 @@ from taskflow.utils import reflection
 ENGINES_NAMESPACE = 'taskflow.engines'
 
 
+def _fetch_factory(factory_name):
+    try:
+        return importutils.import_class(factory_name)
+    except (ImportError, ValueError) as e:
+        raise ImportError("Could not import factory %r: %s"
+                          % (factory_name, e))
+
+
 def _fetch_validate_factory(flow_factory):
     if isinstance(flow_factory, six.string_types):
-        factory_fun = importutils.import_class(flow_factory)
+        factory_fun = _fetch_factory(flow_factory)
         factory_name = flow_factory
     else:
         factory_fun = flow_factory
         factory_name = reflection.get_callable_name(flow_factory)
         try:
-            reimported = importutils.import_class(factory_name)
+            reimported = _fetch_factory(factory_name)
             assert reimported == factory_fun
         except (ImportError, AssertionError):
             raise ValueError('Flow factory %r is not reimportable by name %s'
@@ -46,8 +56,9 @@ def _fetch_validate_factory(flow_factory):
 
 
 def load(flow, store=None, flow_detail=None, book=None,
-         engine_conf=None, backend=None, namespace=ENGINES_NAMESPACE):
-    """Load flow into engine.
+         engine_conf=None, backend=None, namespace=ENGINES_NAMESPACE,
+         **kwargs):
+    """Load a flow into an engine.
 
     This function creates and prepares engine to run the
     flow. All that is left is to run the engine with 'run()' method.
@@ -55,7 +66,7 @@ def load(flow, store=None, flow_detail=None, book=None,
     Which engine to load is specified in 'engine_conf' parameter. It
     can be a string that names engine type or a dictionary which holds
     engine type (with 'engine' key) and additional engine-specific
-    configuration (for example, executor for multithreaded engine).
+    configuration.
 
     Which storage backend to use is defined by backend parameter. It
     can be backend itself, or a dictionary that is passed to
@@ -80,6 +91,15 @@ def load(flow, store=None, flow_detail=None, book=None,
     if isinstance(engine_conf, six.string_types):
         engine_conf = {'engine': engine_conf}
 
+    engine_name = engine_conf['engine']
+    try:
+        pieces = misc.parse_uri(engine_name)
+    except (TypeError, ValueError):
+        pass
+    else:
+        engine_name = pieces['scheme']
+        engine_conf = misc.merge_uri(pieces, engine_conf.copy())
+
     if isinstance(backend, dict):
         backend = p_backends.fetch(backend)
 
@@ -87,23 +107,23 @@ def load(flow, store=None, flow_detail=None, book=None,
         flow_detail = p_utils.create_flow_detail(flow, book=book,
                                                  backend=backend)
 
-    mgr = stevedore.driver.DriverManager(
-        namespace, engine_conf['engine'],
-        invoke_on_load=True,
-        invoke_kwds={
-            'conf': engine_conf.copy(),
-            'flow': flow,
-            'flow_detail': flow_detail,
-            'backend': backend
-        })
-    engine = mgr.driver
-    if store:
-        engine.storage.inject(store)
-    return engine
+    try:
+        mgr = stevedore.driver.DriverManager(
+            namespace, engine_name,
+            invoke_on_load=True,
+            invoke_args=(flow, flow_detail, backend, engine_conf),
+            invoke_kwds=kwargs)
+        engine = mgr.driver
+    except RuntimeError as e:
+        raise exc.NotFound("Could not find engine %s" % (engine_name), e)
+    else:
+        if store:
+            engine.storage.inject(store)
+        return engine
 
 
 def run(flow, store=None, flow_detail=None, book=None,
-        engine_conf=None, backend=None, namespace=ENGINES_NAMESPACE):
+        engine_conf=None, backend=None, namespace=ENGINES_NAMESPACE, **kwargs):
     """Run the flow.
 
     This function load the flow into engine (with 'load' function)
@@ -112,7 +132,7 @@ def run(flow, store=None, flow_detail=None, book=None,
     Which engine to load is specified in 'engine_conf' parameter. It
     can be a string that names engine type or a dictionary which holds
     engine type (with 'engine' key) and additional engine-specific
-    configuration (for example, executor for multithreaded engine).
+    configuration.
 
     Which storage backend to use is defined by backend parameter. It
     can be backend itself, or a dictionary that is passed to
@@ -131,7 +151,7 @@ def run(flow, store=None, flow_detail=None, book=None,
     """
     engine = load(flow, store=store, flow_detail=flow_detail, book=book,
                   engine_conf=engine_conf, backend=backend,
-                  namespace=namespace)
+                  namespace=namespace, **kwargs)
     engine.run()
     return engine.storage.fetch_all()
 
@@ -139,8 +159,7 @@ def run(flow, store=None, flow_detail=None, book=None,
 def save_factory_details(flow_detail,
                          flow_factory, factory_args, factory_kwargs,
                          backend=None):
-    """Saves the given factories reimportable name, args, kwargs into the
-    flow detail.
+    """Saves the given factories reimportable attributes into the flow detail.
 
     This function saves the factory name, arguments, and keyword arguments
     into the given flow details object  and if a backend is provided it will
@@ -177,7 +196,7 @@ def save_factory_details(flow_detail,
 
 def load_from_factory(flow_factory, factory_args=None, factory_kwargs=None,
                       store=None, book=None, engine_conf=None, backend=None,
-                      namespace=ENGINES_NAMESPACE):
+                      namespace=ENGINES_NAMESPACE, **kwargs):
     """Loads a flow from a factory function into an engine.
 
     Gets flow factory function (or name of it) and creates flow with
@@ -210,13 +229,16 @@ def load_from_factory(flow_factory, factory_args=None, factory_kwargs=None,
                          flow_factory, factory_args, factory_kwargs,
                          backend=backend)
     return load(flow=flow, store=store, flow_detail=flow_detail, book=book,
-                engine_conf=engine_conf, backend=backend, namespace=namespace)
+                engine_conf=engine_conf, backend=backend, namespace=namespace,
+                **kwargs)
 
 
 def flow_from_detail(flow_detail):
-    """Recreate flow previously loaded with load_form_factory.
+    """Reloads a flow previously saved.
 
-    Gets flow factory name from metadata, calls it to recreate the flow.
+    Gets the flow factories name and any arguments and keyword arguments from
+    the flow details metadata, and then calls that factory to recreate the
+    flow.
 
     :param flow_detail: FlowDetail that holds state of the flow to load
     """
@@ -228,7 +250,7 @@ def flow_from_detail(flow_detail):
                          % (flow_detail.name, flow_detail.uuid))
 
     try:
-        factory_fun = importutils.import_class(factory_data['name'])
+        factory_fun = _fetch_factory(factory_data['name'])
     except (KeyError, ImportError):
         raise ImportError('Could not import factory for flow %s %s'
                           % (flow_detail.name, flow_detail.uuid))
@@ -239,11 +261,11 @@ def flow_from_detail(flow_detail):
 
 
 def load_from_detail(flow_detail, store=None, engine_conf=None, backend=None,
-                     namespace=ENGINES_NAMESPACE):
-    """Reload flow previously loaded with load_form_factory function.
+                     namespace=ENGINES_NAMESPACE, **kwargs):
+    """Reloads an engine previously saved.
 
-    Gets flow factory name from metadata, calls it to recreate the flow
-    and loads flow into engine with load().
+    This reloads the flow using the flow_from_detail() function and then calls
+    into the load() function to create an engine from that flow.
 
     :param flow_detail: FlowDetail that holds state of the flow to load
     :param store: dict -- data to put to storage to satisfy flow requirements
@@ -256,4 +278,4 @@ def load_from_detail(flow_detail, store=None, engine_conf=None, backend=None,
     flow = flow_from_detail(flow_detail)
     return load(flow, flow_detail=flow_detail,
                 store=store, engine_conf=engine_conf, backend=backend,
-                namespace=namespace)
+                namespace=namespace, **kwargs)
