@@ -16,12 +16,11 @@
 
 import collections
 
-import networkx as nx
 from networkx.algorithms import traversal
 
 from taskflow import exceptions as exc
 from taskflow import flow
-from taskflow.utils import graph_utils
+from taskflow.types import graph as gr
 
 
 class Flow(flow.Flow):
@@ -39,7 +38,8 @@ class Flow(flow.Flow):
 
     def __init__(self, name, retry=None):
         super(Flow, self).__init__(name, retry)
-        self._graph = nx.freeze(nx.DiGraph())
+        self._graph = gr.DiGraph()
+        self._graph.freeze()
 
     def link(self, u, v):
         """Link existing node u as a runtime dependency of existing node v."""
@@ -57,7 +57,7 @@ class Flow(flow.Flow):
             mutable_graph = False
         # NOTE(harlowja): Add an edge to a temporary copy and only if that
         # copy is valid then do we swap with the underlying graph.
-        attrs = graph_utils.get_edge_attrs(graph, u, v)
+        attrs = graph.get_edge_data(u, v)
         if not attrs:
             attrs = {}
         if manual:
@@ -67,21 +67,25 @@ class Flow(flow.Flow):
                 attrs['reasons'] = set()
             attrs['reasons'].add(reason)
         if not mutable_graph:
-            graph = nx.DiGraph(graph)
+            graph = gr.DiGraph(graph)
         graph.add_edge(u, v, **attrs)
         return graph
 
-    def _swap(self, replacement_graph):
-        """Validates the replacement graph and then swaps the underlying graph
-        with a frozen version of the replacement graph (this maintains the
-        invariant that the underlying graph is immutable).
+    def _swap(self, graph):
+        """Validates the replacement graph and then swaps the underlying graph.
+
+        After swapping occurs the underlying graph will be frozen so that the
+        immutability invariant is maintained (we may be able to relax this
+        constraint in the future since our exposed public api does not allow
+        direct access to the underlying graph).
         """
-        if not nx.is_directed_acyclic_graph(replacement_graph):
+        if not graph.is_directed_acyclic():
             raise exc.DependencyFailure("No path through the items in the"
                                         " graph produces an ordering that"
                                         " will allow for correct dependency"
                                         " resolution")
-        self._graph = nx.freeze(replacement_graph)
+        self._graph = graph
+        self._graph.freeze()
 
     def add(self, *items):
         """Adds a given task/tasks/flow/flows to this flow."""
@@ -103,13 +107,13 @@ class Flow(flow.Flow):
 
         if self.retry:
             update_requirements(self.retry)
-            provided.update(dict((k,
-                                  self.retry) for k in self._retry_provides))
+            provided.update(dict((k, self.retry)
+                                 for k in self.retry.provides))
 
         # NOTE(harlowja): Add items and edges to a temporary copy of the
         # underlying graph and only if that is successful added to do we then
         # swap with the underlying graph.
-        tmp_graph = nx.DiGraph(self._graph)
+        tmp_graph = gr.DiGraph(self._graph)
         for item in items:
             tmp_graph.add_node(item)
             update_requirements(item)
@@ -122,7 +126,7 @@ class Flow(flow.Flow):
                         % dict(item=item.name,
                                flow=provided[value].name,
                                value=value))
-                if value in self._retry_requires:
+                if self.retry and value in self.retry.requires:
                     raise exc.DependencyFailure(
                         "Flows retry controller %(retry)s requires %(value)s "
                         "but item %(item)s being added to the flow produces "
@@ -166,22 +170,6 @@ class Flow(flow.Flow):
         for (u, v, e_data) in self._get_subgraph().edges_iter(data=True):
             yield (u, v, e_data)
 
-    @property
-    def provides(self):
-        provides = set()
-        provides.update(self._retry_provides)
-        for subflow in self:
-            provides.update(subflow.provides)
-        return provides
-
-    @property
-    def requires(self):
-        requires = set()
-        requires.update(self._retry_requires)
-        for subflow in self:
-            requires.update(subflow.requires)
-        return requires - self.provides
-
 
 class TargetedFlow(Flow):
     """Graph flow with a target.
@@ -237,5 +225,6 @@ class TargetedFlow(Flow):
         nodes = [self._target]
         nodes.extend(dst for _src, dst in
                      traversal.dfs_edges(self._graph.reverse(), self._target))
-        self._subgraph = nx.freeze(self._graph.subgraph(nodes))
+        self._subgraph = self._graph.subgraph(nodes)
+        self._subgraph.freeze()
         return self._subgraph
