@@ -16,11 +16,26 @@
 
 import mock
 
+import taskflow.engines
+from taskflow import exceptions as exc
+from taskflow.patterns import linear_flow
 from taskflow import test
 from taskflow.tests import utils as test_utils
 from taskflow.utils import persistence_utils as p_utils
 
-import taskflow.engines
+
+class EngineLoadingTestCase(test.TestCase):
+    def test_default_load(self):
+        f = linear_flow.Flow('test')
+        f.add(test_utils.TaskOneReturn("run-1"))
+        e = taskflow.engines.load(f)
+        self.assertIsNotNone(e)
+
+    def test_unknown_load(self):
+        f = linear_flow.Flow('test')
+        f.add(test_utils.TaskOneReturn("run-1"))
+        self.assertRaises(exc.NotFound, taskflow.engines.load, f,
+                          engine_conf='not_really_any_engine')
 
 
 class FlowFromDetailTestCase(test.TestCase):
