@@ -1,7 +1,5 @@
 # -*- coding: utf-8 -*-
 
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 #    Copyright (C) 2012 Yahoo! Inc. All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -18,12 +16,11 @@
 
 import contextlib
 
-from taskflow import task
-from taskflow import test
-
 import taskflow.engines
 from taskflow.patterns import linear_flow as lf
 from taskflow.persistence.backends import impl_memory
+from taskflow import task
+from taskflow import test
 from taskflow.utils import persistence_utils as p_utils
 
 
@@ -51,6 +48,7 @@ class TestProgress(test.TestCase):
                                   flow_detail=flow_detail,
                                   backend=backend)
         e.compile()
+        e.prepare()
         return e
 
     def tearDown(self):
@@ -100,10 +98,10 @@ class TestProgress(test.TestCase):
             b, fd = p_utils.temporary_flow_detail(be)
             e = self._make_engine(flo, flow_detail=fd, backend=be)
             e.run()
-            t_uuid = e.storage.get_uuid_by_name("test")
-            end_progress = e.storage.get_task_progress(t_uuid)
+            end_progress = e.storage.get_task_progress("test")
             self.assertEqual(1.0, end_progress)
-            td = fd.find(t_uuid)
+            task_uuid = e.storage.get_atom_uuid("test")
+            td = fd.find(task_uuid)
             self.assertEqual(1.0, td.meta['progress'])
             self.assertFalse(td.meta['progress_details'])
 
@@ -111,10 +109,9 @@ class TestProgress(test.TestCase):
         flo = ProgressTaskWithDetails("test")
         e = self._make_engine(flo)
         e.run()
-        t_uuid = e.storage.get_uuid_by_name("test")
-        end_progress = e.storage.get_task_progress(t_uuid)
+        end_progress = e.storage.get_task_progress("test")
         self.assertEqual(1.0, end_progress)
-        end_details = e.storage.get_task_progress_details(t_uuid)
+        end_details = e.storage.get_task_progress_details("test")
         self.assertEqual(end_details.get('at_progress'), 0.5)
         self.assertEqual(end_details.get('details'), {
             'test': 'test data',
@@ -136,10 +133,10 @@ class TestProgress(test.TestCase):
             e = self._make_engine(flo, flow_detail=fd, backend=be)
             e.run()
 
-            t_uuid = e.storage.get_uuid_by_name("test")
-            end_progress = e.storage.get_task_progress(t_uuid)
+            end_progress = e.storage.get_task_progress("test")
             self.assertEqual(1.0, end_progress)
-            td = fd.find(t_uuid)
+            task_uuid = e.storage.get_atom_uuid("test")
+            td = fd.find(task_uuid)
             self.assertEqual(1.0, td.meta['progress'])
             self.assertFalse(td.meta['progress_details'])
             self.assertEqual(6, len(fired_events))
