@@ -15,14 +15,14 @@
 #    under the License.
 
 import multiprocessing
+import threading
 
-import six
+from six.moves import _thread
 
-if six.PY2:
-    from thread import get_ident  # noqa
-else:
-    # In python3+ the get_ident call moved (whhhy??)
-    from threading import get_ident  # noqa
+
+def get_ident():
+    """Return the 'thread identifier' of the current thread."""
+    return _thread.get_ident()
 
 
 def get_optimal_thread_count():
@@ -34,3 +34,13 @@ def get_optimal_thread_count():
         # just setup two threads since it's hard to know what else we
         # should do in this situation.
         return 2
+
+
+def daemon_thread(target, *args, **kwargs):
+    """Makes a daemon thread that calls the given target when started."""
+    thread = threading.Thread(target=target, args=args, kwargs=kwargs)
+    # NOTE(skudriashev): When the main thread is terminated unexpectedly
+    # and thread is still alive - it will prevent main thread from exiting
+    # unless the daemon property is set to True.
+    thread.daemon = True
+    return thread
